@@ -2,7 +2,14 @@ pub mod crypto;
 pub(crate) mod git;
 pub mod store;
 pub mod sync;
+#[cfg(all(feature = "tomb", target_os = "linux"))]
+pub mod systemd_bin;
+#[cfg(all(feature = "tomb", target_os = "linux"))]
+pub mod tomb;
+#[cfg(all(feature = "tomb", target_os = "linux"))]
+pub(crate) mod tomb_bin;
 pub mod types;
+pub mod util;
 mod vendor;
 
 #[cfg(test)]
